import { FocusMonitor, FocusOrigin } from '@angular/cdk/a11y';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * Checkbox state for aria-checked property
 */
export declare const enum eCheckboxAriaState {
    TRUE = "true",
    FALSE = "false",
    MIXED = "mixed"
}
export declare class BaoCheckboxComponent implements ControlValueAccessor, AfterViewInit, OnInit, OnDestroy {
    private elementRef;
    private cdr;
    private focusMonitor;
    /**
     * The checkbox ID. It is set dynamically with an unique ID by default
     */
    id: string;
    /**
     * The aria-label for web accessibility
     */
    ariaLabel?: string;
    /**
     * Whether the checkbox has a border and is considered as a card.
     */
    brandBorder: boolean;
    /**
     * Whether the checkbox is inline.
     */
    inline: boolean;
    /**
     * The name property of the checkbox
     */
    name?: string;
    /**
     * The visible state of the label
     */
    hiddenLabel: boolean;
    /**
     * Emitted object on change event
     */
    readonly change: EventEmitter<boolean>;
    /**
     * Inderminate value of the checkbox whenever
     */
    readonly indeterminateChange: EventEmitter<boolean>;
    /**
     * Reference to the input html element
     */
    private inputElement;
    /**
     * The aria-describedby id for web accessibilty
     */
    ariaDescribedby?: string;
    /**
     * The aria-labeledby id for web accessibilty
     */
    ariaLabelledby?: string;
    /**
     * The ID of the input html element
     */
    inputID: string;
    private _disabled;
    private _checked;
    private _indeterminate;
    private _uniqueId;
    private _required;
    constructor(elementRef: ElementRef<HTMLElement>, cdr: ChangeDetectorRef, focusMonitor: FocusMonitor);
    /**
     * Whether the checkbox is checked.  Default value : false
     */
    get checked(): boolean;
    /**
     * Whether the checkbox is disabled. Default value : false
     */
    get disabled(): boolean;
    /**
     * Whether the checkbox is required.  Default value : false
     */
    get required(): boolean;
    /**
     * Whether the checkbox is indeterminate.  Default value : false
     */
    get indeterminate(): boolean;
    get nativeElement(): HTMLElement;
    set checked(value: boolean);
    set disabled(value: boolean);
    set required(value: boolean);
    set indeterminate(value: boolean);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Implement ControlValueAccessor
     */
    writeValue(value: any): void;
    /**
     * Implement ControlValueAccessor
     */
    registerOnChange(fn: (value: any) => void): void;
    /**
     * Implement ControlValueAccessor
     */
    registerOnTouched(fn: any): void;
    /**
     * Implement ControlValueAccessor
     */
    setDisabledState(isDisabled: boolean): void;
    focus(origin?: FocusOrigin, options?: FocusOptions): void;
    /**
     * Whenever there is change on the input html element
     */
    onInteractionEvent(event: Event): void;
    /**
     * Whenever there is click event triggered on the checkbox
     */
    onInputClick(event: Event): void;
    /**
     * Get the value for the aria-checked property (web accessibility)
     */
    getAriaState(): eCheckboxAriaState;
    /**
     * Emit new values whenever the checkbox object has change.
     */
    private emitChangeEvent;
    /**
     * Set the checked property on the input html element
     */
    private syncChecked;
    /**
     * Set the indeterminate property on the input html element
     */
    private syncIndeterminate;
    /**
     * Set the aria-describedby property to bao-checkbox-description
     */
    private setAriaDescribedByToDescription;
    /**
     * Set checked value
     */
    private toggle;
    private onModelChange;
    private onTouch;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoCheckboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoCheckboxComponent, "bao-checkbox, [bao-checkbox]", never, { "id": { "alias": "id"; "required": false; }; "ariaLabel": { "alias": "aria-label"; "required": false; }; "brandBorder": { "alias": "brandBorder"; "required": false; }; "inline": { "alias": "inline"; "required": false; }; "name": { "alias": "name"; "required": false; }; "hiddenLabel": { "alias": "hiddenLabel"; "required": false; }; "checked": { "alias": "checked"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "required": { "alias": "required"; "required": false; }; "indeterminate": { "alias": "indeterminate"; "required": false; }; }, { "change": "change"; "indeterminateChange": "indeterminateChange"; }, never, ["*", "bao-checkbox-description, [bao-checkbox-description], [baoCheckboxDescription]"], false, never>;
}
export declare class BaoCheckBoxDescription {
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoCheckBoxDescription, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoCheckBoxDescription, "bao-checkbox-description, [bao-checkbox-description],  [baoCheckboxDescription]", never, {}, {}, never, never, false, never>;
}
