import { Overlay } from '@angular/cdk/overlay';
import { DomPortal } from '@angular/cdk/portal';
import { AfterContentInit, AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, QueryList, Renderer2, SimpleChanges } from '@angular/core';
import * as i0 from "@angular/core";
export declare class BaoDropdownMenuItem implements AfterViewInit, OnChanges {
    private renderer;
    private elementRef;
    private _parent;
    /**
     * Is the list item disabled
     */
    disabled: boolean;
    /**
     * Emits when menu item is clicked
     */
    itemClicked: EventEmitter<any>;
    constructor(renderer: Renderer2, elementRef: ElementRef<HTMLElement>, _parent: BaoDropdownMenuComponent);
    get nativeElement(): HTMLElement;
    spaceKeyEvent(): void;
    onClick(el: HTMLElement): void;
    enterKeyEvent(): void;
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** Regroups label and description in a new div to help with layout */
    private addContentDiv;
    private addPaddingClass;
    private disableItem;
    /**
     * This method propagates a click event to menu item children with inputs (checkbox, radio button).
     * It emits event to close menu if item does not contain an input.
     */
    private propagateClick;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuItem, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoDropdownMenuItem, "bao-dropdown-menu-item, [bao-dropdown-menu-item]", never, { "disabled": { "alias": "disabled"; "required": false; }; }, { "itemClicked": "itemClicked"; }, never, never, false, never>;
}
export declare class BaoDropdownMenuComponent implements AfterContentInit, AfterViewInit {
    private cdr;
    private renderer;
    private elementRef;
    /**
     * Fired when the dropdown-menu changes its 'isOpen' value
     */
    isOpenChange: EventEmitter<boolean>;
    /**
     * Fired when menu is closed by key event triggered from menu item
     */
    isClosedByKeyEvent: EventEmitter<any>;
    /**
     * Content of menu to be loaded inside Overlay
     */
    _menuContent: ElementRef<HTMLElement>;
    /**
     * All list items inside menu
     */
    _listItems: QueryList<BaoDropdownMenuItem>;
    /**
     * Unique identifier of the dropdown menu
     */
    readonly menuId: string;
    /**
     * Is the dropwdown menu currently open
     */
    private _isOpen;
    /**
     * Reference to portal which is attached to Overlay
     */
    private _menuPortal;
    /**
     * Index of currently active list item
     */
    private _activeItemIndex;
    constructor(cdr: ChangeDetectorRef, renderer: Renderer2, elementRef: ElementRef<HTMLElement>);
    get isOpen(): boolean;
    get activeItemIndex(): number;
    get menuPortal(): DomPortal;
    get nativeElement(): HTMLElement;
    set isOpen(isOpen: boolean);
    set activeItemIndex(index: number);
    upKeyEvent(): void;
    downKeyEvent(): void;
    /** Prevents focus to be lost when TAB has reached end of menu  */
    tabKeyEvent(): void;
    tabUpKeyEvent(): void;
    /** Prevents focus to be lost when SHIFT + TAB has reached beginning of menu  */
    shiftTabKeyEvent(event: KeyboardEvent): void;
    ngAfterViewInit(): void;
    ngAfterContentInit(): void;
    open(): void;
    close(): void;
    focus(): void;
    /** Move the aria-current attribute to new active page */
    setNavigationAttribute(activePageElement: HTMLElement): void;
    private focusNextItem;
    /**
     * Finds the next activable tab index when navigating with up and down arrow or TAB keys
     * @param currentIndex List item index which currently has focus
     * @param isDown Whether the navigation is going in the down direction or not
     * @param isBackward If recursive function is going backward looking for last activable item in list
     * @returns Index of the next item that will receive focus
     */
    private getNextActivableItemIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoDropdownMenuComponent, "bao-dropdown-menu", never, {}, { "isOpenChange": "isOpenChange"; "isClosedByKeyEvent": "isClosedByKeyEvent"; }, ["_listItems"], ["*"], false, never>;
}
/**
 * Directive to be applied on element that will trigger the opening and closing of menu.
 */
export declare class BaoDropdownMenuTrigger implements AfterViewInit, OnDestroy {
    private renderer;
    private elementRef;
    private overlay;
    menu: BaoDropdownMenuComponent | null;
    private _overlayRef;
    private _isMenuOpen;
    constructor(renderer: Renderer2, elementRef: ElementRef<HTMLElement>, overlay: Overlay);
    get nativeElement(): HTMLElement;
    escapeKeyEvent(): void;
    onClick(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private toggleMenu;
    private closeMenu;
    private openMenu;
    private createOverlay;
    private getOverlayConfig;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuTrigger, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoDropdownMenuTrigger, "bao-dropdown-menu-trigger, [bao-dropdown-menu-trigger], [baoDropdownMenuTriggerFor]", never, { "menu": { "alias": "baoDropdownMenuTriggerFor"; "required": false; }; }, {}, never, never, false, never>;
}
/**
 * Sections of list items in menu. Apply proper styling to section's title if there is one.
 */
export declare class BaoDropdownMenuSection implements AfterViewInit {
    private elementRef;
    private renderer;
    constructor(elementRef: ElementRef<HTMLElement>, renderer: Renderer2);
    get nativeElement(): HTMLElement;
    ngAfterViewInit(): void;
    private insertTitle;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuSection, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoDropdownMenuSection, "bao-dropdown-menu-section, [bao-dropdown-menu-section]", never, {}, {}, never, never, false, never>;
}
/**
 * Label of a list item, add css class to apply proper styling.
 */
export declare class BaoDropdownMenuItemLabel {
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuItemLabel, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoDropdownMenuItemLabel, "bao-dropdown-menu-item-label, [bao-dropdown-menu-item-label]", never, {}, {}, never, never, false, never>;
}
/**
 * Description of a list item, add css class to apply proper styling.
 */
export declare class BaoDropdownMenuItemDescription {
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuItemDescription, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoDropdownMenuItemDescription, "bao-dropdown-menu-item-description, [bao-dropdown-menu-item-description]", never, {}, {}, never, never, false, never>;
}
/**
 * Divider to separate sections.
 */
export declare class BaoDropdownMenuDivider implements AfterContentInit {
    private renderer;
    private elementRef;
    constructor(renderer: Renderer2, elementRef: ElementRef<HTMLElement>);
    get nativeElement(): HTMLElement;
    ngAfterContentInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoDropdownMenuDivider, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoDropdownMenuDivider, "bao-dropdown-menu-divider, [bao-dropdown-menu-divider]", never, {}, {}, never, never, false, never>;
}
