import { AfterContentInit, AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, Renderer2 } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BaoFileIntl } from './file-intl';
import * as i0 from "@angular/core";
export declare class BaoFileInputComponent implements AfterContentInit, AfterViewInit, OnDestroy, ControlValueAccessor {
    intl: BaoFileIntl;
    private elementRef;
    private renderer;
    private cdr;
    /**
     * Id of the file input field
     */
    inputId?: string;
    /**
     * Label of field to be displayed above
     */
    label: string;
    /**
     * Size of the file input label
     */
    size: 'small' | 'medium';
    /**
     * Maximum size accepted for uploaded files
     */
    maximalFileSize: number;
    /**
     * Accepted types of files
     */
    acceptedMIMETypes: string[];
    /**
     * Is field required
     */
    required?: boolean;
    /**
     * Is field disabled
     */
    disabled?: boolean;
    /**
     * File selected to be uploaded
     */
    uploadedFile: EventEmitter<File>;
    /**
     * List of files that have been uploaded so far
     */
    private _files;
    /**
     * Form errors when component is used in a form
     */
    private _errorForm;
    /**
     * Error texts
     */
    private _errorTexts;
    /**
     * File input that triggers uploading when clicked
     */
    private uploader;
    private dropzoneElement;
    insertDefaultInstructions: boolean;
    isFileTooBig: boolean;
    isFileTypeInvalid: boolean;
    private _value;
    private _intlChanges;
    private _helperTextId;
    constructor(intl: BaoFileIntl, elementRef: ElementRef<HTMLElement>, renderer: Renderer2, cdr: ChangeDetectorRef);
    get nativeElement(): HTMLElement;
    enterKeyEvent(): void;
    tabKeyEvent(): void;
    shiftTabKeyEvent(): void;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Implements ControlValueAccessor interface
     */
    writeValue(obj: any): void;
    /**
     * Implements ControlValueAccessor interface
     */
    registerOnChange(fn: (value: any) => void): void;
    /**
     * Implements ControlValueAccessor interface
     */
    registerOnTouched(fn: any): void;
    /**
     * Implements ControlValueAccessor interface
     */
    setDisabledState(isDisabled: boolean): void;
    uploadFile(file: File): void;
    /**
     * Saves the registerOnChange function so the component can call it whenever it wants.
     */
    propagateChange: (_: any) => void;
    /**
     * Saves the registerOnTouched function so the component can call it whenever it wants.
     */
    propagateTouched: () => void;
    private setValue;
    private setDescribedByAttribute;
    private setErrorTextsAttribute;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoFileInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoFileInputComponent, "bao-file-input, [bao-file-input]", never, { "inputId": { "alias": "id"; "required": false; }; "label": { "alias": "label"; "required": false; }; "size": { "alias": "size"; "required": false; }; "maximalFileSize": { "alias": "maximalFileSize"; "required": false; }; "acceptedMIMETypes": { "alias": "acceptedMIMETypes"; "required": false; }; "required": { "alias": "required"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, { "uploadedFile": "uploadedFile"; }, ["_files", "_errorForm"], ["bao-guiding-text", "bao-file-dropzone-instructions", "bao-error", "*"], false, never>;
}
export declare class BaoFileDropDirective {
    fileDrop: EventEmitter<File>;
    private _isDragOver;
    onDragOver(event: DragEvent): void;
    onDragLeave(event: DragEvent): void;
    onDrop(event: DragEvent): void;
    private preventAndStop;
    private getDataTransfer;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoFileDropDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoFileDropDirective, "[baoFileDrop]", never, {}, { "fileDrop": "fileDrop"; }, never, never, false, never>;
}
export declare class BaoFileDropzoneIntructions implements AfterContentInit {
    private renderer;
    private elementRef;
    constructor(renderer: Renderer2, elementRef: ElementRef<HTMLElement>);
    get nativeElement(): HTMLElement;
    ngAfterContentInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoFileDropzoneIntructions, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoFileDropzoneIntructions, "bao-file-dropzone-instructions, [bao-file-dropzone-instructions]", never, {}, {}, never, never, false, never>;
}
