import { InjectionToken, Injector, OnDestroy, TemplateRef, Type } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { BaoModalContainer, _BaoModalContainerBase } from './modal-container';
import { BaoModalRef } from './modal-ref';
import { BaoModalConfig } from './modal-config';
import { ComponentType, Overlay, OverlayContainer } from '@angular/cdk/overlay';
import * as i0 from "@angular/core";
/** Injection token that can be used to access the data that was passed in to a modal. */
export declare const BAO_MODAL_DATA: InjectionToken<unknown>;
export declare abstract class BaoModalBase<C extends _BaoModalContainerBase> implements OnDestroy {
    private _overlay;
    private _injector;
    private _parentModal;
    private _overlayContainer;
    private _modalRefConstructor;
    private _modalContainerType;
    private _modalDataToken;
    readonly afterAllClosed: Observable<void>;
    private _openModalsAtThisLevel;
    private readonly _afterAllClosedAtThisLevel;
    private readonly _afterOpenedAtThisLevel;
    private _ariaHiddenElements;
    private _modalAnimatingOpen;
    private _animationStateSubscriptions;
    private _lastModalRef;
    constructor(_overlay: Overlay, _injector: Injector, _parentModal: BaoModalBase<C> | undefined, _overlayContainer: OverlayContainer, _modalRefConstructor: Type<BaoModalRef<unknown>>, _modalContainerType: Type<C>, _modalDataToken: InjectionToken<unknown>);
    /** Keeps track of the currently-open modals. */
    get openModals(): BaoModalRef<unknown>[];
    /** Stream that emits when a modal has been opened. */
    get afterOpened(): Subject<BaoModalRef<unknown>>;
    getAfterAllClosed(): Subject<void>;
    /**
     * Opens a modal modal containing the given template.
     */
    open<T>(componentOrTemplateRef: ComponentType<T> | TemplateRef<T>, config?: BaoModalConfig): BaoModalRef<unknown>;
    /**
     * Closes all of the currently-open modals.
     */
    closeAll(): void;
    /**
     * Finds an open modal by its id.
     */
    getModalById(id: string): BaoModalRef<unknown> | undefined;
    ngOnDestroy(): void;
    /**
     * Creates the overlay into which the modal will be loaded.
     */
    private _createOverlay;
    /**
     * Creates an overlay config from a modal config.
     */
    private _getOverlayConfig;
    /**
     * Attaches a modal container to a modal's already-created overlay.
     */
    private _attachModalContainer;
    /**
     * Attaches the user-provided component to the already-created modal container.
     */
    private _attachModalContent;
    /**
     * Creates a custom injector to be used inside the modal. This allows a component loaded inside
     * of a modal to close itself and, optionally, to return a value.
     */
    private _createInjector;
    /**
     * Removes a modal from the array of open modals.
     */
    private _removeOpenModal;
    /**
     * Hides all of the content that isn't an overlay from assistive technology.
     */
    private _hideNonModalContentFromAssistiveTechnology;
    /** Closes all of the modals in an array. */
    private _closeModals;
    /**
     * Applies default options to the modal config.
     */
    private _applyConfigDefaults;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoModalBase<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoModalBase<any>, never, never, {}, {}, never, never, false, never>;
}
/**
 * Service to open modal.
 */
export declare class BaoModal extends BaoModalBase<BaoModalContainer> {
    constructor(overlay: Overlay, injector: Injector, parentModal: BaoModal, overlayContainer: OverlayContainer);
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoModal, [null, null, { optional: true; skipSelf: true; }, null]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BaoModal>;
}
