import { AfterContentInit, AfterViewInit, ChangeDetectorRef, EventEmitter, InjectionToken } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BaoRadioButtonComponent } from '.';
import * as i0 from "@angular/core";
/**
 * We have to inject the radio button group and all its children to each child.
 */
export declare const BAO_RADIO_GROUP: InjectionToken<BaoRadioButtonGroupComponent>;
export declare class BaoRadioButtonGroupComponent implements AfterContentInit, ControlValueAccessor, AfterViewInit {
    private cdr;
    /**
     * The checkbox group ID. It is set dynamically with an unique ID by default
     */
    id: string;
    /**
     * Emit the value of the selected radio button
     */
    readonly change: EventEmitter<string>;
    private staticContainer;
    /**
     * The aria-describedby for web accessibilty
     */
    ariaDescribedby: string | null;
    private _radios;
    private _value;
    private _name;
    private _selected;
    private _isInitialized;
    private _disabled;
    private _required;
    private _uniqueId;
    constructor(cdr: ChangeDetectorRef);
    /**
     * Define the name property of all radio buttons. Default : null
     */
    get name(): string | null;
    /**
     * Define the value of the selected radio button. Default : null
     */
    get value(): string | null;
    /**
     * Define which radio button is selected. Default : null
     */
    get selected(): BaoRadioButtonComponent | null;
    /**
     * Whether the radio button groupd is disabled. Default : false
     */
    get disabled(): boolean;
    /**
     * Whether the radio button groupd is required. Default : false
     */
    get required(): boolean;
    set name(value: string | null);
    set value(newValue: string | null);
    set selected(selected: BaoRadioButtonComponent | null);
    set disabled(value: boolean);
    set required(value: boolean);
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    /**
     * Implement ControlValueAccessor
     */
    writeValue(value: string): void;
    /**
     * Implement ControlValueAccessor
     */
    registerOnChange(fn: (value: any) => void): void;
    /**
     * Implement ControlValueAccessor
     */
    registerOnTouched(fn: any): void;
    /**
     * Implement ControlValueAccessor
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * onTouch() called from the button children
     */
    onGroupTouch(): void;
    /**
     * Update all radio button name
     */
    updateRadioButtonNames(): void;
    /**
     * Define which radio button is selected.
     */
    updateSelectedRadioFromValue(): void;
    /**
     * Update checked property on selected radio button
     */
    checkSelectedRadioButton(): void;
    /**
     * Emit the value of the new selected radio button
     */
    emitChangeEvent(): void;
    /**
     * Call markForCheck function on all radio buttons since one of the parent inputs could't have change meanwhile. Prevent change detection error.
     */
    markRadiosForCheck(): void;
    onContentChange(): void;
    onModelChange: (value: any) => void;
    /**
     * Set the aria-describedby property to bao-guiding-text if available
     */
    private setAriaDescribedByToDescription;
    private showAriaDescribedBy;
    private onTouch;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoRadioButtonGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoRadioButtonGroupComponent, "bao-radio-button-group, [bao-radio-button-group], [baoRadioButtonGroup]", ["baoRadioGroup"], { "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "value": { "alias": "value"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "change": "change"; }, ["staticContainer"], ["*", "bao-error, [bao-error], bao-guiding-text, [bao-guiding-text]"], false, never>;
}
