import { FocusMonitor, FocusOrigin } from '@angular/cdk/a11y';
import { UniqueSelectionDispatcher } from '@angular/cdk/collections';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { BaoRadioButtonGroupComponent } from './radio-group.component';
import * as i0 from "@angular/core";
export declare class BaoRadioButtonComponent implements AfterViewInit, OnInit, OnDestroy {
    private elementRef;
    private cdr;
    private focusMonitor;
    private radioDispatcher;
    /**
     * The radio button ID. It is set dynamically with an unique ID by default
     */
    id: string;
    /**
     * The aria-label for web accessibility
     */
    ariaLabel: string | null;
    /**
     * Whether the radio button has a border and is considered as a card.
     */
    brandBorder: boolean;
    /**
     * Whether the radio button is inline.
     */
    inline: boolean;
    /**
     * The name property of the radio button
     */
    name: string | null;
    /**
     * The visible state of the label
     */
    hiddenLabel: boolean;
    /**
     * Emitted boolean on change
     */
    readonly change: EventEmitter<string>;
    /**
     * Reference to the input html element
     */
    private inputElement;
    /**
     * The radio buttons group
     */
    radioGroup: BaoRadioButtonGroupComponent;
    /**
     * The aria-describedby id for web accessibilty
     */
    ariaDescribedby: string | null;
    /**
     * The aria-labeledby id for web accessibilty
     */
    ariaLabelledby: string | null;
    /**
     * The ID of the input html element
     */
    inputID: string;
    private _checked;
    private _disabled;
    private _required;
    private _value;
    private _uniqueId;
    constructor(radioGroup: BaoRadioButtonGroupComponent, elementRef: ElementRef<HTMLElement>, cdr: ChangeDetectorRef, focusMonitor: FocusMonitor, radioDispatcher: UniqueSelectionDispatcher);
    /**
     * Whether the radio button is checked. Default : false
     */
    get checked(): boolean;
    /**
     * Define the radio button value. Default : null
     */
    get value(): string;
    /**
     * Whether the radio button is disabled. Default : false
     */
    get disabled(): boolean;
    /**
     * Whether the radio button is required. Default : false
     */
    get required(): boolean;
    get nativeElement(): HTMLElement;
    set checked(value: boolean);
    set value(value: string);
    set disabled(value: boolean);
    set required(value: boolean);
    focus(options?: FocusOptions, origin?: FocusOrigin): void;
    /**
     * Method called from the parent as one of the parent input has changed. Prevent change detection error.
     */
    markForCheck(): void;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Emit the new value from the selected radio-button and the parent
     */
    onInputInteraction(event: Event): void;
    private emitChangeEvent;
    private setDisabled;
    /**
     * Set the id property to bao-radio-button-description as a description to the input
     */
    private setAriaDescribedByToDescription;
    /** Unregister function for radioDispatcher */
    private _removeUniqueSelectionListener;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoRadioButtonComponent, [{ optional: true; }, null, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaoRadioButtonComponent, "bao-radio-button, [bao-radio-button]", never, { "id": { "alias": "id"; "required": false; }; "ariaLabel": { "alias": "aria-label"; "required": false; }; "brandBorder": { "alias": "brandBorder"; "required": false; }; "inline": { "alias": "inline"; "required": false; }; "name": { "alias": "name"; "required": false; }; "hiddenLabel": { "alias": "hiddenLabel"; "required": false; }; "checked": { "alias": "checked"; "required": false; }; "value": { "alias": "value"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "change": "change"; }, never, ["*", "bao-radio-button-description, [bao-radio-button-description], [baoRadioButtonDescription]"], false, never>;
}
export declare class BaoRadioDescription {
    static ɵfac: i0.ɵɵFactoryDeclaration<BaoRadioDescription, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaoRadioDescription, "bao-radio-button-description, [bao-radio-button-description],  [baoRadioButtonDescription]", never, {}, {}, never, never, false, never>;
}
