import { AriaLivePoliteness } from '@angular/cdk/a11y';
import { Direction } from '@angular/cdk/bidi';
import { InjectionToken, ViewContainerRef } from '@angular/core';
/** Injection token that can be used to access the data that was passed in to a snack bar. */
export declare const BAO_SNACK_BAR_DATA: InjectionToken<any>;
/** Possible values for horizontalPosition on MatSnackBarConfig. */
export type BaoSnackBarHorizontalPosition = 'start' | 'center' | 'end' | 'left' | 'right';
/** Possible values for verticalPosition on MatSnackBarConfig. */
export type BaoSnackBarVerticalPosition = 'top' | 'bottom';
/** Possible types of toast to display the snack bar */
export type BaoSnackBarToastType = 'info' | 'success' | 'danger';
/**
 * Configuration used when opening a snack-bar.
 */
export declare class BaoSnackBarConfig<D = any> {
    /** The message to display in the snackbar. */
    message: string;
    /** The type of snackbar template to display. */
    toastType?: BaoSnackBarToastType;
    /**
     * The attached action to the snack bar. If the name of the action matches an icon provided as part of
     * angular-ui icon dictionnary an icon will be displayed instead of text.
     * */
    actionLabelOrIcon?: string;
    /** Displays the close button when set to true */
    showClose?: boolean;
    /** The length of time in milliseconds to wait before automatically dismissing the snack bar. */
    duration?: number;
    /** The politeness level for the MatAriaLiveAnnouncer announcement. */
    politeness?: AriaLivePoliteness;
    /**
     * Message to be announced by the LiveAnnouncer. When opening a snackbar without a custom
     * component or template, the announcement message will default to the specified message.
     */
    announcementMessage?: string;
    /**
     * The view container that serves as the parent for the snackbar for the purposes of dependency
     * injection. Note: this does not affect where the snackbar is inserted in the DOM.
     */
    viewContainerRef?: ViewContainerRef;
    /** Extra CSS classes to be added to the snack bar container. */
    panelClass?: string | string[];
    /** Text layout direction for the snack bar. */
    direction?: Direction;
    /** Data being injected into the child component. */
    data?: D | null;
    /** The horizontal position to place the snack bar. */
    horizontalPosition?: BaoSnackBarHorizontalPosition;
    /** The vertical position to place the snack bar. */
    verticalPosition?: BaoSnackBarVerticalPosition;
}
